==> e2b-0.17.2a41-py3-none-any.whl: e2b/api/client/models/post_sandboxes_sandbox_id_refreshes_body.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PostSandboxesSandboxIDRefreshesBody")


@_attrs_define
class PostSandboxesSandboxIDRefreshesBody:
    """
    Attributes:
        duration (Union[Unset, int]): Duration for which the sandbox should be kept alive in seconds
    """

    duration: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        duration = self.duration

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if duration is not UNSET:
            field_dict["duration"] = duration

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        duration = d.pop("duration", UNSET)

        post_sandboxes_sandbox_id_refreshes_body = cls(
            duration=duration,
        )

        post_sandboxes_sandbox_id_refreshes_body.additional_properties = d
        return post_sandboxes_sandbox_id_refreshes_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> e2b-1.2.0b3-py3-none-any.whl: e2b/api/client/models/post_sandboxes_sandbox_id_refreshes_body.py <==
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PostSandboxesSandboxIDRefreshesBody")


@_attrs_define
class PostSandboxesSandboxIDRefreshesBody:
    """
    Attributes:
        duration (Union[Unset, int]): Duration for which the sandbox should be kept alive in seconds
    """

    duration: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        duration = self.duration

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if duration is not UNSET:
            field_dict["duration"] = duration

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        duration = d.pop("duration", UNSET)

        post_sandboxes_sandbox_id_refreshes_body = cls(
            duration=duration,
        )

        post_sandboxes_sandbox_id_refreshes_body.additional_properties = d
        return post_sandboxes_sandbox_id_refreshes_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
